@@ -1109,7 +1109,7 @@ class ProblemService:
                 tests = TestcaseService.load_testcases(testcase_file)
                 print(f"reading testcases in file {testcase_file}: {len(tests)}")
                 for t in tests:
-                    _input, _output, _name = t['input'], t['output'], t['name']
+                    _input, _output, _name = t.input, t.output, t.name
                     # print(f"Input: {input}, output: {output}")
                     if "_sample" in file_name:
                         if _input not in [t.input for t in problem.testcases_sample]:
