@@ -180,7 +180,7 @@ class TestcaseService:
             for input_file in input_files:
                 if input_file.lower().endswith(".inp"):
                     output_file = TestcaseService.\
-                        find_name_from_list_ignore_case(input_file.replace(".inp", ".out"), all_files)
+                        find_name_from_list_ignore_case(input_file.lower().replace(".inp", ".out"), all_files)
                 elif input_file.lower().startswith("input") or "/input" in input_file.lower():
                     output_file = TestcaseService.\
                         find_name_from_list_ignore_case(input_file.lower().replace("input", "output"), all_files)
