@@ -7,6 +7,7 @@ __author__ = 'ThucNC'
 import configparser
 import mimetypes
 import os
+from datetime import datetime
 from typing import List, Union
 
 import requests
@@ -229,6 +230,28 @@ class UCode:
 
             return problem
 
+    def get_question_from_quiz(self, quiz_id, save_to_folder=".", testcase_format="ucode"):
+        url = self.get_api_url(f"/lesson-item/{quiz_id}/question")
+        response = self.s.get(url, headers=self._headers)
+        print(url)
+        print("status_code:", response.status_code)
+        data_json = response.json()
+        if not data_json['success']:
+            CLog.error(f"Fail to get quiz #{quiz_id}: {json.dumps(data_json)}")
+            return
+
+        questions_json = data_json['data']
+        print(json.dumps(questions_json))
+        # questions = []
+        save_to_folder = os.path.join(save_to_folder, f"quiz_{quiz_id}")
+        os.makedirs(save_to_folder, exist_ok=True)
+        for question_json in questions_json:
+            ques_id = question_json['id']
+            CLog.info(f"Start downloading problem #{ques_id}")
+            problem = self.get_question(ques_id, download_testcases=True)
+            ProblemService.save(problem, save_to_folder, testcase_format=testcase_format)
+            # questions.append(question)
+
     def add_question_to_quiz(self, question_ids: List[int], quiz_id: int):
         url = self.get_api_url(f"/lesson-item/{quiz_id}/add-question")
         payload = {
@@ -246,6 +269,36 @@ class UCode:
         else:
             CLog.error("Cannot add questions to quiz:" + json.dumps(res))
 
+    def add_question_to_daily_challenge(self, question_id: int, ucoin: int, date: str, status: str="draft"):
+        """
+
+        @param question_id:
+        @param ucoin:
+        @param date:
+        @param status: draft / published
+        @return:
+        """
+        url = self.get_api_url(f"/challenge-problem/upsert")
+        start_date = datetime.fromisoformat(date + " 07:00:00+07:00")
+        end_date = datetime.fromisoformat(date + " 23:59:59+07:00")
+        payload = {
+            "question_id": question_id,
+            "status": status,
+            "start_date": int(start_date.timestamp()),
+            "end_date": int(end_date.timestamp()),
+            "ucoin": ucoin,
+        }
+
+        response = self.s.post(url, json=payload, headers=self._headers)
+        print("status_code:", response.status_code)
+        print(url)
+        print(response.text)
+        res = response.json()
+        if res['success']:
+            print(f"Questions #{question_id} ({ucoin} ucoins) successfully added to daily challenge at {start_date}")
+        else:
+            CLog.error("Cannot add questions to quiz:" + json.dumps(res))
+
     def create_problem(self, problem: Union[Question, Problem, str],
                        score=10, xp=10, lang='vi', statement_format="markdown", question_type='code',
                        status="published", visibility="unlisted", request_approval=False):
@@ -266,7 +319,8 @@ class UCode:
 
             ucoin = xp
             if ucoin < 0:
-                ucoin = int(round(50 * problem.difficulty**1.5, -2))
+                # ucoin = int(round(50 * problem.difficulty**1.5, -2))
+                ucoin = int(round(2 * 50 * problem.difficulty**1.1, -2))//2
             if ucoin <= 0:
                 ucoin = 100
             data = {
@@ -593,6 +647,52 @@ class UCode:
                 raise Exception("Cannot lesson item:" + json.dumps(res))
         return lesson_item_id
 
+    def get_course_curriculum(self, course_id, save_to_folder=None, get_quizes=False):
+        url = self.get_api_url(f"/curriculum/{course_id}/course-items")
+        response = self.s.get(url, headers=self._headers)
+        print(url)
+        print("status_code:", response.status_code)
+        data_json = response.json()
+        if not data_json['success']:
+            CLog.error(f"Fail to get curriculum of course #{course_id}: {json.dumps(data_json)}")
+            return
+
+        curriculum = data_json['data']
+
+        for chapter in curriculum:
+            items = chapter['items']
+            for item in items:
+                if item['item_type'] == "lesson":
+                    for lesson_item in item['items']:
+                        lesson_item.update(self.get_lesson_item(lesson_item['lesson_item_id']))
+                        if get_quizes and lesson_item['content_type'] == 'quiz':
+                            quiz_id = lesson_item['lesson_item_id']
+                            self.get_question_from_quiz(quiz_id, save_to_folder)
+                else: # lesson_item
+                    item.update(self.get_lesson_item(item['lesson_item_id']))
+                    if get_quizes and item['content_type'] == 'quiz':
+                        quiz_id = item['lesson_item_id']
+                        self.get_question_from_quiz(quiz_id, save_to_folder)
+
+        print(json.dumps(curriculum, indent=2, ensure_ascii=False))
+        if save_to_folder:
+            with open(os.path.join(save_to_folder, f"course_{course_id}.json"), 'w', encoding="utf-8") as f:
+                f.write(json.dumps(curriculum, indent=2, ensure_ascii=False))
+        return curriculum
+
+    def get_lesson_item(self, lesson_item):
+        url = self.get_api_url(f"/lesson-item/{lesson_item}")
+        response = self.s.get(url, headers=self._headers)
+        print(url)
+        print("status_code:", response.status_code)
+        data_json = response.json()
+        if not data_json['success']:
+            CLog.error(f"Fail to get lesson item #{lesson_item}: {json.dumps(data_json)}")
+            return
+
+        lesson_item = data_json['data']
+        return lesson_item
+
 
 def create_chapters_mc1():
     ucode = UCode("dev")
@@ -830,15 +930,59 @@ def test_get_question():
     ProblemService.save(problem, save_to, overwrite=True, testcase_format="themis")
 
 
-if __name__ == "__main__":
+def test_get_questions_from_quiz():
+    env, domain = "prod", "ucode.vn"
+    ucode = UCode(env=env, domain=domain)
+    quiz_id = 3892
+    save_to = r"D:\projects\ucode\ucode-cli\problems\_save"
+
+    ucode.get_question_from_quiz(quiz_id, save_to_folder=save_to)
+
+
+def add_to_daily_challenge():
     test_login()
+    ucode = UCode(env="prod", domain="ucode.vn")
+
+    date = "2021-10-27"
+    folder = r"D:\projects\ucode\dsa-problem-bank\HTDung\2021-10\daily_challenges\challenge_002"
+    problems = ProblemService.read_all_problems(folder, nested_folder=False)
+
+    for i, (problem_folder, problem) in enumerate(problems):
+        problem = ProblemService.load(problem_folder, load_testcase=True)
+        print(i + 1, problem.name, "testcases:", len(problem.testcases), ", sample test:",
+              len(problem.testcases_sample))
+
+        prob_id = ucode.create_problem(problem=problem, xp=-1, score=100)
+        ucoin = [500,1000,2000][i]
+        CLog.info(f"Created problem: {prob_id}")
+        ucode.add_question_to_daily_challenge(question_id=prob_id, ucoin=ucoin,
+                                              date=date, status="published")
+        print(f"Problem uploaded with id #{prob_id} and added to challenge {date}")
+
+
+def test_get_course_curriculum():
+    env, domain = "prod", "ucode.vn"
+    ucode = UCode(env=env, domain=domain)
+    # course_id = 822
+    course_id = 13
+    save_to = r"D:\projects\ucode\ucode-cli\problems\_save"
+
+    ucode.get_course_curriculum(course_id, save_to_folder=save_to, get_quizes=True)
+
+
+if __name__ == "__main__":
+    # test_login()
     # teko_bb()
     # reupload_testcases()
 
     # create_problems_to_lesson_ucode("prod", domain="teko.ugrow.vn")
     # create_problems_to_lesson_ucode("prod")
 
-    test_get_question()
+    # test_get_question()
+    # test_get_questions_from_quiz()
+    # test_get_course_curriculum()
+
+    add_to_daily_challenge()
 
     # create_problem("dev")
     # create_problem("prod", domain="teko.ugrow.vn")
